/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.common;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.Hashtable;
import java.util.Map;

import junit.framework.Test;

import org.eclipse.cosmos.rm.validation.internal.launcher.ResourceValidation;
import org.eclipse.hyades.test.common.junit.DefaultTestArbiter;
import org.eclipse.hyades.test.common.junit.HyadesTestCase;
import org.eclipse.hyades.test.common.junit.HyadesTestSuite;

/**
 * Generated code for the test suite <b>TestFileOutput</b> located at
 * <i>/org.eclipse.cosmos.rm.validation.tests/plugin-junits/TestFileOutput.testsuite</i>.
 */
public class TestFileOutput extends HyadesTestCase
{
	/**
	 * Constructor for TestFileOutput.
	 * 
	 * @param name
	 */
	public TestFileOutput(String name)
	{
		super(name);
	}

	/**
	 * Returns the JUnit test suite that implements the <b>TestFileOutput</b> definition.
	 */
	public static Test suite()
	{
		HyadesTestSuite testFileOutput = new HyadesTestSuite("TestFileOutput");
		testFileOutput.setArbiter(DefaultTestArbiter.INSTANCE).setId("FD8E8DCE363780617B2D499078B911DB");
		testFileOutput.addTest(new TestFileOutput("testFileOutput").setId("FD8E8DCE36378061971CC6D078B911DB").setTestInvocationId("FD8E8DCE363780616AF2AA6078BA11DB"));
		return testFileOutput;
	}

	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	protected void setUp() throws Exception
	{
	}

	/**
	 * @see junit.framework.TestCase#tearDown()
	 */
	protected void tearDown() throws Exception
	{
	}

	/**
	 * testFileOutput
	 * 
	 * @throws Exception
	 */
	public void testFileOutput() throws Exception
	{
		Map attributes = new Hashtable();
		final String ACTUAL_FILE_PATH = "D:/temp/actual.txt";
		attributes.put(ResourceValidation.ATTRIBUTE_FILE_OUTPUT, ACTUAL_FILE_PATH);
		FileOutput fo = new FileOutput();
		
		fo.initialize(attributes);
		fo.reportError("Message");
		fo.reportWarning("Message");
		fo.reportInfo("Message");
		
		fo.close();
		
		BufferedReader expectedResults = new BufferedReader(new InputStreamReader(this.getClass().getClassLoader().getResourceAsStream("expected-results/fileoutput.txt")));
		BufferedReader actualResults = new BufferedReader(new InputStreamReader(new FileInputStream(ACTUAL_FILE_PATH)));
		
		String currentExpectedLine = null;
		while ((currentExpectedLine = expectedResults.readLine()) != null)
		{
			assertEquals("The content of the generated file is different than the expected file", currentExpectedLine, actualResults.readLine());
		}
		
		assertNull("The actual file has more content than expected", actualResults.readLine());
		actualResults.close();
	}

}
